;; Generated package description from greader.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "greader" "0.19.5.0.20260627.0" "Gnamù reader, send buffer contents to a speech engine" '((emacs "26.1") (seq "2.24") (compat "29.1.4.5")) :commit "5c304ad008d8688e4eccd9947ba5e410399bf021" :authors '(("Michelangelo Rodriguez" . "michelangelo.rodriguez@gmail.com")) :maintainer '("Michelangelo Rodriguez" . "michelangelo.rodriguez@gmail.com") :keywords '("tools" "accessibility") :url "https://gitlab.com/michelangelo-rodriguez/greader")
